@@ -7,7 +7,7 @@ use PerlIO::encoding;
 $Data::Dumper::Sortkeys = 1;
 use FASTX::Seq;
 use File::Basename;
-$FASTX::Reader::VERSION = '1.10.0';
+$FASTX::Reader::VERSION = '1.12.0';
 require Exporter;
 our @ISA = qw(Exporter);
 
@@ -22,9 +22,8 @@ sub new {
     my $self = bless {} => $class;
     my $args = {};
     
-    # Named parameters
-
-    if (substr($_[0], 0, 1) eq '-') {
+    # Named parameters: undefined $_[0] will read STDIN!
+    if (defined $_[0] and substr($_[0], 0, 1) eq '-') {
       my %data = @_;
         # Try parsing
         for my $i (keys %data) {
@@ -484,7 +483,7 @@ FASTX::Reader - A simple module to parse FASTA and FASTQ files, supporting compr
 
 =head1 VERSION
 
-version 1.10.0
+version 1.12.0
 
 =head1 SYNOPSIS
 
@@ -497,6 +496,14 @@ version 1.10.0
     print $seq->{name}, "\t", $seq->{seq}, "\t", $seq->{qual}, "\n";
   }
 
+=head1 NAME
+
+FASTX::Reader - A simple module to parse FASTA and FASTQ files, supporting compressed files and paired-ends.
+
+=head1 VERSION
+
+version 1.11.0
+
 =head1 BUILD TEST
 
 Every CPAN release is tested by the L<CPAN testers grid|http://matrix.cpantesters.org/?dist=FASTX-Reader>.
@@ -635,6 +642,18 @@ Andrea Telatin <andrea@telatin.com>
 
 This software is Copyright (c) 2019 by Andrea Telatin.
 
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 AUTHOR
+
+Andrea Telatin <andrea@telatin.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2019 by Andrea Telatin.
+
 This is free software, licensed under:
 
   The MIT (X11) License
